# FeatureFlag

Controls an Agilicus feature's settings
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**feature** | **str** | The name of the feature | 
**enabled** | **bool** | Whether the feature is enabled | 
**setting** | **str** | a specific setting for the feature | [optional] [default to '']

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


